summaryrefslogtreecommitdiffstats
path: root/src/ClientHandle.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ClientHandle.h')
-rw-r--r--src/ClientHandle.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ClientHandle.h b/src/ClientHandle.h
index 0e588d839..25dd250d9 100644
--- a/src/ClientHandle.h
+++ b/src/ClientHandle.h
@@ -280,8 +280,8 @@ public:
void HandleEntityLeaveBed (int a_EntityID);
void HandleEntitySprinting (int a_EntityID, bool a_IsSprinting);
- /** Kicks the current player if the same username is already logged in.
- Returns false if a player has been kicked, true otherwise. */
+ /** Kicks the client if the same username is already logged in.
+ Returns false if the client has been kicked, true otherwise. */
bool CheckMultiLogin(const AString & a_Username);
/** Called when the protocol handshake has been received (for protocol versions that support it;